@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- encoding: UTF8 -*-
 
 #######################################################################
@@ -7,8 +7,7 @@
 #
 #######################################################################
 
-from cryptdomainmgr.modules.common.cdmconfighelper import applyDefault, processConfig
-from simpleloggerplus import simpleloggerplus as log
+from cryptdomainmgr.modules.common.cdmconfighelper import processConfig
 
 
 # Default handling
@@ -26,12 +25,7 @@ def interpreteValues(args):
         certconfig[certSecName]['keysize'] = int(content['keysize'])
     if 'extraflags' in content:
         certconfig[certSecName]['extraflags'] = [e for e in content['extraflags'].replace(' ', '').split(',') if len(e) > 0]
-    if 'conflictingservices' in content:
-        conflictingservices = content['conflictingservices'].replace(' ', '').split(',')
-        if '' == conflictingservices[0]:
-            conflictingservices = []
-        certconfig[certSecName]['conflictingservices'] = conflictingservices
 
 def interpreteConfig(cr, sh):
-    return processConfig(cr, 'cert', postOp=interpreteValues, defaultConfig={'keysize': 4096, 'extraflags': ''})
+    return processConfig(cr, 'cert', postOp=interpreteValues, defaultConfig={'handler': 'dehydrated/letsencrypt', 'keysize': 4096, 'extraflags': ''})
 
