@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- encoding: UTF8 -*-
 
 #######################################################################
@@ -17,11 +17,11 @@ def splitList(content):
     return {k: [e.strip() for e in v.split(',')] for k, v in content.items()}
 
 def parseNestedEntry(key, value, default = [], keySplitPattern = '.', valueSplitPattern = ':'):
-    if keySplitPattern is None:
+    if keySplitPattern == '':
         keyList = [key]
     else:
         keyList   = key.split(keySplitPattern)
-    if valueSplitPattern is None:
+    if valueSplitPattern == '':
         valueList = [value]
     else:
         valueList = value.split(valueSplitPattern)
@@ -29,15 +29,18 @@ def parseNestedEntry(key, value, default = [], keySplitPattern = '.', valueSplit
     rv = {}
     subtractMode = False
     if '+' == keyList[-1][-1]:
-        keyList[-1] = keyList[-1][:-1]
+        keyList[-1] = keyList[-1][:-1].strip()
     elif '-' == keyList[-1][-1]:
-        keyList[-1] = keyList[-1][:-1]
+        keyList[-1] = keyList[-1][:-1].strip()
         subtractMode = True
     else:
         rv['delList'] = list(keyList)
     addList[:len(keyList)] = list(keyList)
     for i, e in enumerate(valueList):
-        addList[-i] = e
+        try:
+            addList[-i] = e
+        except IndexError:
+            log.warn('Too many arguments in parameter!')
     if subtractMode is True:
         rv['delListWithContent'] = addList
     else:
@@ -112,19 +115,19 @@ def interpreteRR(content, rrType = 'mx', defaultList = ['*', '10'], keySplitPatt
     return {'{}AggrAdd'.format(rrType): aggrAdd, '{}AggrDel'.format(rrType): aggrDel}
 
 def interpreteCAA(content):
-    return interpreteRR(content, 'caa', ['*', '*', '*'], '.', ' ')
+    return interpreteRR(content, 'caa', ['*', '*', '*'], '.', None) # None = one or more spaces
 
 def interpreteMX(content):
     return interpreteRR(content, 'mx', ['*', '10'])
 
 def interpreteSRV(content):
-    return interpreteRR(content, 'srv', ['*', '*', '*', '*', '50', '10'])
+    return interpreteRR(content, 'srv', ['*', 'http', 'tcp', '443', '0', '0'])
 
 def interpreteA(content):
     return interpreteRR(content, 'ip4', ['*'])
 
 def interpreteAAAA(content):
-    return interpreteRR(content, 'ip6', ['*'], None, None)
+    return interpreteRR(content, 'ip6', ['*'], '', '') # '' = do not split
 
 def interpreteDKIM(content):
     return interpreteRR(content, 'dkim', ['*', '*'])
@@ -141,6 +144,13 @@ def interpreteSOA(content):
 def interpreteSPF(content):
     return interpreteSetRR(content, 'spf', ['*'])
 
+def interpreteCert(content):
+    if 'cert' not in content:
+        return {}
+    certNames = content['cert'].replace(' ','').split(',')
+    return {'cert': certNames}
+
+
 def interpreteHandler(content):
     if 'handler' not in content:
         return {}
@@ -155,7 +165,7 @@ def interpreteDictRR(content, rrType):
     return {}
 
 def interpreteSetRR(content, rrType, defaultList = ['*']):
-    rrList = interpreteRR(content, rrType, defaultList)
+    rrList = interpreteRR(content, rrType, defaultList, '', '')
     rrSet = {k: set([e for e in v if '' != e]) for k, v in rrList.items()}
     return rrSet
 
@@ -163,7 +173,7 @@ def interpreteConfig(cr, sh):
     domainconfigOrig = cr.getRawConfigOf('domain', True)
     domainconfig = applyDefault(domainconfigOrig) # must be here because following section depends on default values
     for domain, content in domainconfig.items():
-        for f in ['A', 'AAAA', 'DKIM', 'TLSA', 'MX', 'SRV', 'CAA', 'DMARC', 'SOA', 'SPF', 'Handler']:
+        for f in ['A', 'AAAA', 'DKIM', 'TLSA', 'MX', 'SRV', 'CAA', 'DMARC', 'SOA', 'SPF', 'Handler', 'Cert']:
             domainconfig[domain].update((globals()['interprete{}'.format(f)](content)))
     log.debug(domainconfig)
     cr.updateConfig({'domain': domainconfig})
