@@ -10,14 +10,14 @@
 
 import unittest
 
-from cryptdomainmgr.cdmconfighandler import *
+from cryptdomainmgr.cdmconfighandler import ConfigReader
 
 def procConfig(cr):
     cr.open()
     cr.interprete(None)
     return cr
 
-class TestCDMconfigcandler(unittest.TestCase):
+class TestCDMconfighandler(unittest.TestCase):
     def testNoSection(self):
         cr = ConfigReader()
         cr.setContentList([''])
@@ -36,9 +36,15 @@ class TestCDMconfigcandler(unittest.TestCase):
         procConfig(cr)
         self.assertEqual({'cdm': {'statedir': '/var/cryptdomainmgr', 'x': '3'}}, cr.config)
 
+    def testCDMDefaultSectionSimpleVal2(self):
+        cr = ConfigReader()
+        cr.setContentList(['[cdm] \n x = 3 \n '])
+        procConfig(cr)
+        self.assertEqual({'cdm': {'statedir': '/var/cryptdomainmgr', 'x': '3'}}, cr.config)
+
     def testCDMDefaultSectionDefaultOverwrite(self):
         cr = ConfigReader()
-        cr.setContentList(['[cdm]\nstatedir=/blub\n'])
+        cr.setContentList([' [cdm] \n statedir = /blub \n '])
         procConfig(cr)
         self.assertEqual({'cdm': {'statedir': '/blub'}}, cr.config)
 
